"""This package defines types hints used by the streamunolib library."""

from typing import Callable, Protocol, runtime_checkable


@runtime_checkable
class ExposableCallable(Protocol):
    """Interface of all components that can be exposed or hidden."""

    __call__: Callable
    __exposed__: bool



"""This package provides the decorators to annotate a transform component."""

from typing import Callable, Union, cast

from .types import ExposableCallable


def exposed(f: Union[Callable, ExposableCallable]) -> ExposableCallable:
    """Marks a function as a UI-visible transform component."""
    f.__exposed__ = True  # type: ignore
    return cast(ExposableCallable, f)


def hidden(f: Union[Callable, ExposableCallable]) -> ExposableCallable:
    """Marks a function as a non UI-visible transform component."""
    f.__exposed__ = False  # type: ignore
    return cast(ExposableCallable, f)



"""The streamUno library.

This library provides generic components to construct transforms and decorators
to annotate these components.
"""
from .decorators import exposed, hidden

__all__ = ['exposed', 'hidden']
